@@ -28,6 +28,7 @@ from __future__ import absolute_import
 
 import six
 
+from autobahn.util import public
 from autobahn.wamp.uri import error
 
 __all__ = (
@@ -42,12 +43,14 @@ __all__ = (
 )
 
 
+@public
 class Error(RuntimeError):
     """
     Base class for all exceptions related to WAMP.
     """
 
 
+@public
 class SessionNotReady(Error):
     """
     The application tried to perform a WAMP interaction, but the
@@ -55,6 +58,7 @@ class SessionNotReady(Error):
     """
 
 
+@public
 class SerializationError(Error):
     """
     Exception raised when the WAMP serializer could not serialize the
@@ -62,6 +66,7 @@ class SerializationError(Error):
     """
 
 
+@public
 class ProtocolError(Error):
     """
     Exception raised when WAMP protocol was violated. Protocol errors
@@ -70,6 +75,7 @@ class ProtocolError(Error):
     """
 
 
+@public
 class TransportLost(Error):
     """
     Exception raised when the transport underlying the WAMP session
@@ -77,6 +83,7 @@ class TransportLost(Error):
     """
 
 
+@public
 class ApplicationError(Error):
     """
     Base class for all exceptions that can/may be handled
@@ -195,7 +202,6 @@ class ApplicationError(Error):
     A *Peer* was authenticated for an authid that does not or longer exists.
     """
 
-    # FIXME: this currently isn't used neither in Autobahn nor Crossbar. Check!
     CANCELED = u"wamp.error.canceled"
     """
     A Dealer or Callee canceled a call previously issued (WAMP AP).
@@ -209,27 +215,40 @@ class ApplicationError(Error):
     exclusion of (any) *Callee* providing the procedure (WAMP AP).
     """
 
-    # application payload end-to-end encryption related errors
-    ENC_NO_KEYRING_ACTIVE = u"wamp.error.encryption.no_keyring_active"
+    ENC_NO_PAYLOAD_CODEC = u"wamp.error.no_payload_codec"
+    """
+    WAMP message in payload transparency mode received, but no codec set
+    or codec did not decode the payload.
+    """
+
     ENC_TRUSTED_URI_MISMATCH = u"wamp.error.encryption.trusted_uri_mismatch"
+    """
+    WAMP-cryptobox application payload end-to-end encryption error.
+    """
+
     ENC_DECRYPT_ERROR = u"wamp.error.encryption.decrypt_error"
+    """
+    WAMP-cryptobox application payload end-to-end encryption error.
+    """
 
     def __init__(self, error, *args, **kwargs):
         """
 
         :param error: The URI of the error that occurred, e.g. ``wamp.error.not_authorized``.
-        :type error: unicode
+        :type error: str
         """
         Exception.__init__(self, *args)
         self.kwargs = kwargs
         self.error = error
         self.enc_algo = kwargs.pop('enc_algo', None)
 
+    @public
     def error_message(self):
         """
         Get the error message of this exception.
 
-        :return: unicode
+        :returns: The error message.
+        :rtype: str
         """
         return u'{0}: {1}'.format(
             self.error,
